pub struct LookupError(pub String);Expand description
Error type for reporting issues during the lookup of the Issuer Public Key.
Tuple Fields
0: StringTrait Implementations
impl BhError for LookupError
Sourceimpl Debug for LookupError
impl Debug for LookupError
Sourceimpl Display for LookupError
impl Display for LookupError
Sourceimpl PartialEq for LookupError
impl PartialEq for LookupError
Sourcefn eq(&self, other: &LookupError) -> bool
fn eq(&self, other: &LookupError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LookupError