pub struct Disclosure { /* private fields */ }Expand description
A disclosure for a JSON node in the VC, in both parsed form and the original serialized form.
Implementations
Sourceimpl Disclosure
impl Disclosure
Sourcepub fn new(salt: String, claim_name: Option<String>, claim_value: Value) -> Self
pub fn new(salt: String, claim_name: Option<String>, claim_value: Value) -> Self
Construct a new Disclosure from the given salt, claim_name and claim_value.
Sourcepub fn claim_name(&self) -> Option<&str>
pub fn claim_name(&self) -> Option<&str>
Disclosure data key, i.e. claim name.
Sourcepub fn into_string(self) -> String
pub fn into_string(self) -> String