pub struct KeyBindingChallenge {
pub aud: String,
pub nonce: String,
}Expand description
The challenge to be sent to the holder. The purpose of the challenge is to ensure the freshness of the key binding signature, as well as the proper audience.
Fields
aud: Stringnonce: StringA value used to ensure the freshness of the signature, as specified here.