JsonNodePath

Type Alias JsonNodePath 

pub type JsonNodePath<'a> = [JsonNodePathSegment<'a>];
Type of JSON node paths, represented as a list of segments to follow starting from the root of the JWT.

Not to be confused with the JSONPath query syntax.