pub enum HashingAlgorithm {
Sha256,
}Expand description
An identifier of the algorithm used for hashing. All the algorithm variants
are deemed secure for the SD-JWT purposes.
The string value of the algorithm is used in the _sd_alg field of the
SD-JWT, formatted as specified in the IANA Named Information Hash
Algorithm Registry.
The default algorithm is SHA-256, as specified here.
The HashingAlgorithm can be parsed from string, expecting the same
format as specified above.
Variants
Sha256
SHA-256 algorithm for hashing.
Implementations
Sourceimpl HashingAlgorithm
impl HashingAlgorithm
Sourcepub fn as_str(&self) -> &'static str
pub fn as_str(&self) -> &'static str
Returns the string value of the algorithm, formatted as specified in the IANA Named Information Hash Algorithm Registry.